@@ -154,7 +154,7 @@ class CRYSTOUT(object):
     def __init__(self, filename, **kwargs):
 
         self.data = ''              # file contents
-        self.pdata = None
+        self.pdata = None           # PROPERTIES part
         self.properties_calc, self.crystal_calc = False, False
 
         self.info = {
@@ -247,16 +247,15 @@ class CRYSTOUT(object):
                 self.data = raw_data[parts_pointer[0]: parts_pointer[1]]
                 self.pdata = raw_data[parts_pointer[1]:]
                 self.properties_calc, self.crystal_calc = True, True
-        else:
+
+        elif len(parts_pointer) == 1:
             if not CRYSTOUT.is_properties(raw_data[parts_pointer[0]:]):
-                self.data = raw_data[parts_pointer[0]:]
-                self.crystal_calc = True
+                self.data, self.crystal_calc = raw_data[parts_pointer[0]:], True
             else:
-                self.pdata = raw_data[parts_pointer[0]:]
-                self.properties_calc = True
+                self.pdata, self.properties_calc = raw_data[parts_pointer[0]:], True
 
         if not self.crystal_calc and not self.properties_calc:
-            raise CRYSTOUT_Error('Though this file looks similar to CRYSTAL output, its format is unknown!')
+            raise CRYSTOUT_Error('Although this looks similar to CRYSTAL output, the format is unknown!')
 
         if self.crystal_calc:
             self.info['duration'], self.info['timestamp'] = self.get_timings()
@@ -342,7 +341,7 @@ class CRYSTOUT(object):
 
     @staticmethod
     def detect(test_string):
-        if "*                              MAIN AUTHORS" in test_string:
+        if b"*                              MAIN AUTHORS" in test_string:
             return True
         return False
 
@@ -350,14 +349,14 @@ class CRYSTOUT(object):
     def acceptable(filename):
         open_close = isinstance(filename, (str, PurePath))
         if open_close:
-            f = open(filename, 'r')
+            f = open(filename, 'rb')
         else:
             f = filename
 
         counter = 0
 
         while counter < 700:
-            fingerprint = f.readline()
+            fingerprint = f.read(32768)
             if CRYSTOUT.detect(fingerprint):
                 if open_close:
                     f.close()
